@@ -376,6 +376,17 @@ sub tab_changed # SLOT: ( QWidget * )
       fpc_mgr      -> update ();
     }
   }
+  elsif ($tab_index == 2)	# copy
+  {
+    if (dev && elapsed_label -> text () eq "0:00:00")
+    {
+      my $capacity = $dvdr_total_sectors - $dvdr_spare_sectors;
+      my $selected = vts_list_items -> nr_of_selected_sectors ();
+      my $tgt_size = $capacity;
+      $tgt_size    = $selected if ($tgt_size > $selected);
+      dst_space_label -> setText (sprintf "0/%d MB", $tgt_size / 512.);
+    }
+  }
   elsif ($tab_index == 4)	# settings
   {
     settings_is_current = 1;
@@ -398,7 +409,7 @@ sub tab_changed # SLOT: ( QWidget * )
        &trUtf8 ("dvdauthor version"), $dvdauthor_version,
        &trUtf8 ("Operating system"), $Config {"osname"},
        &trUtf8 ("Machine architecture"), $Config {"archname"},
-       &trUtf8 ("User interface language"), read_setting ("/General/language"),
+       &trUtf8 ("User interface language"), $::lang,
        &trUtf8 ("Installation prefix"), read_setting ("/Installation/prefix"),
        &trUtf8 ("Load prefix"), $QVamps::load_prefix,
        &trUtf8 ("qVamps home"), $QVamps::qvamps_home,
@@ -467,54 +478,31 @@ sub copy_or_abort
   }
 
   my $capacity = $dvdr_total_sectors - $dvdr_spare_sectors;
-  my $vap_fact = (vts_list_items -> nr_of_selected_sectors () + 0.0) /
-                   $capacity;
+  my $selected = vts_list_items -> nr_of_selected_sectors ();
+  my $vap_fact = ($selected + 0.0) / $capacity;
+  my $tgt_size = $capacity;
   $vap_fact = 1.0 if ($vap_fact < 1.0);
+  $tgt_size = $selected if ($tgt_size > $selected);
 
   my $base_path = make_base_path (dvd_dir_edit -> text ());
 
   mkpath ($base_path);
 
+  my $stat;
   my $mtable_items     = mtable_items;
   my $menu_box_checked = menu_check_box               -> isChecked ();
   my $fpc_box_checked  = fpc_check_box                -> isChecked ();
   my $ignore_errors    = ignore_read_errors_check_box -> isChecked ();
+  my $rm_temps         = !keep_temps_check_box        -> isChecked ();
+  my $dump_mode        = radio_button_4               -> isChecked ();
   my $add_unseen       = $menu_box_checked && !$mtable_items -> nr_of_items ();
+  my $dst_dir          = $dump_mode ? "mpegs" : "image/VIDEO_TS";
   $mtable_items -> update ($add_unseen);
   fpc_mgr       -> update ();
 
-  my $xml_writer = XmlWriter (dev, dvd, title_list_items, vts_list_items,
-			      fpc_mgr, $mtable_items, $vap_fact, $base_path,
-			      $ignore_errors, this, "xml_writer");
-
-  my $stat = $xml_writer -> write ($fpc_box_checked, $menu_box_checked);
-  $stat  ||= $xml_writer -> close ();
-  undef $xml_writer;
-
-  return if ($stat);
-
-  my $menu_preview = menu_preview;
-  $menu_preview -> generate (this);
-
-  my $make_menu = $menu_box_checked && $mtable_items -> nr_of_items ();
-
-  if ($make_menu)
-  {
-    my $menu_writer = MenuWriter (mtable_items, $menu_preview,
-				  $base_path, this, "menu_writer");
-
-    $stat   = $menu_writer -> write_xml ();
-    $stat ||= $menu_writer -> close ();
-    $stat ||= $menu_writer -> write_images ();
-
-    return if ($stat);
-  }
-
-  my $disk_change = disk_change_check_box -> isChecked ();
-  my $rm_temps    = !keep_temps_check_box -> isChecked ();
-  my $vol_id      = vol_id_edit -> text ();
-
-  $dvd_maker     = DvdMaker (copy_log_viewer, this, "copy_dvd_maker");
+  $dvd_maker     = DvdMaker (copy_log_viewer, elapsed_label,
+			     dst_space_label, $tgt_size / 512.,
+			     "$base_path/$dst_dir", this, "copy_dvd_maker");
   copy_dvd_maker = $dvd_maker;
 
   my $button      = copy_button;
@@ -522,47 +510,90 @@ sub copy_or_abort
   $button     -> setText (&trUtf8 ("Abort"));
   load_button -> setEnabled (0);
 
-  $stat = $dvd_maker -> write_script ($base_path, $make_menu,
-				      $disk_change, $rm_temps, $vol_id);
-
-  if (!$stat &&
-      (radio_button_2 -> isChecked () || radio_button_3 -> isChecked ()))
+  unless ($dump_mode)
   {
-    $stat   = $dvd_maker -> run_spumux ($base_path, $make_menu, $rm_temps);
-    $stat ||= $dvd_maker -> run_dvdauthor ($base_path, $rm_temps);
+    my $xml_writer = XmlWriter (dev, dvd, title_list_items, vts_list_items,
+				fpc_mgr, $mtable_items, $vap_fact, $base_path,
+				$ignore_errors, this, "xml_writer");
 
-    $stat ||= !open FH, ">", "$base_path/volume_id.txt";
-    $stat ||= !print FH "$vol_id\n";
-    $stat ||= !close FH;
+    $stat   = $xml_writer -> write ($fpc_box_checked, $menu_box_checked);
+    $stat ||= $xml_writer -> close ();
+    undef $xml_writer;
 
-    if (!$stat && radio_button_3 -> isChecked ())
+    return if ($stat);
+
+    my $menu_preview = menu_preview;
+    $menu_preview -> generate (this);
+
+    my $make_menu = $menu_box_checked && $mtable_items -> nr_of_items ();
+
+    if ($make_menu)
     {
-      if ($disk_change)
+      my $menu_writer = MenuWriter (mtable_items, $menu_preview,
+				    $base_path, this, "menu_writer");
+
+      $stat   = $menu_writer -> write_xml ();
+      $stat ||= $menu_writer -> close ();
+      $stat ||= $menu_writer -> write_images ();
+
+      return if ($stat);
+    }
+
+    my $disk_change = disk_change_check_box -> isChecked ();
+    my $vol_id      = vol_id_edit -> text ();
+
+    $stat = $dvd_maker -> write_script ($base_path, $make_menu,
+					$disk_change, $rm_temps, $vol_id);
+
+    if (!$stat &&
+	(radio_button_2 -> isChecked () || radio_button_3 -> isChecked ()))
+    {
+      $stat   = $dvd_maker -> run_spumux ($base_path, $make_menu, $rm_temps);
+      $stat ||= $dvd_maker -> run_dvdauthor ($base_path, $rm_temps);
+
+      $stat ||= !open FH, ">", "$base_path/volume_id.txt";
+      $stat ||= !print FH "$vol_id\n";
+      $stat ||= !close FH;
+
+      if (!$stat && radio_button_3 -> isChecked ())
       {
-	unload (1);
+	if ($disk_change)
+	{
+	  unload (1);
 
-	my $cmd = read_setting ("/General/disk_change_cmd");
-	system ("$cmd &") if ($cmd);
+	  my $cmd = read_setting ("/General/disk_change_cmd");
+	  system ("$cmd &") if ($cmd);
 
-	info (&trUtf8 ("Please insert blank DVD into burner"));
+	  info (&trUtf8 ("Please insert blank DVD into burner"));
+	}
+
+	$stat = $dvd_maker -> run_burn_cmd ($base_path, $vol_id);
+
+	copy_sub_frame -> setEnabled (0) if ($disk_change);
       }
 
-      $stat = $dvd_maker -> run_burn_cmd ($base_path, $vol_id);
-
-      copy_sub_frame -> setEnabled (0) if ($disk_change);
-    }
-
-    if ($stat)
-    {
-      my $cmd = read_setting ("/General/burn_failed_cmd");
-      system ("$cmd &") if ($cmd);
-    }
-    else
-    {
-      my $cmd = read_setting ("/General/burn_done_cmd");
-      system ("$cmd &") if ($cmd);
+      if ($stat)
+      {
+	my $cmd = read_setting ("/General/burn_failed_cmd");
+	system ("$cmd &") if ($cmd);
+      }
+      else
+      {
+	my $cmd = read_setting ("/General/burn_done_cmd");
+	system ("$cmd &") if ($cmd);
+      }
     }
   }
+  else
+  {
+    # create MPEG files only
+    my $mpg_dumper = MpgDumper (dev, dvd, $dvd_maker, title_list_items,
+				vts_list_items, $vap_fact, $base_path,
+				$ignore_errors, this, "mpg_dumper");
+    $stat = $mpg_dumper -> run ($rm_temps);
+  }
+
+  undef $dvd_maker;
 
   $button     -> setText ($button_text);
   $button     -> setEnabled (1);
@@ -570,6 +601,8 @@ sub copy_or_abort
 
   if (copy_dvd_maker)
   {
+    copy_dvd_maker = undef;
+
     if ($stat)
     {
       error ('<font color="#ff0000">' . &trUtf8 ("Copy failed!") . '</font> ' .
@@ -584,8 +617,6 @@ sub copy_or_abort
   {
     info (&trUtf8 ("Copy aborted!"));
   }
-
-  copy_dvd_maker = undef;
 }
 
 
@@ -613,7 +644,8 @@ sub tools_run_dvdauthor_or_abort
     return;
   }
 
-  $dvd_maker      = DvdMaker (tools_log_viewer, this, "tools_dvd_maker");
+  $dvd_maker      = DvdMaker (tools_log_viewer, undef, undef,
+			      0, undef, this, "tools_dvd_maker");
   tools_dvd_maker = $dvd_maker;
 
   my $button      = tools_dvdauthor_button;
@@ -693,7 +725,8 @@ sub tools_burn_or_abort
     $vol_id    =~ s/(.{1,29}).*/$1_QV/;
   }
 
-  $dvd_maker      = DvdMaker (tools_log_viewer, this, "tools_dvd_maker");
+  $dvd_maker      = DvdMaker (tools_log_viewer, undef, undef,
+			      0, undef, this, "tools_dvd_maker");
   tools_dvd_maker = $dvd_maker;
 
   my $button      = tools_burn_button;
