@@ -25,23 +25,40 @@ use DesignerMimeSourceFactory_qvamps;
 
 
 my $app    = Qt::Application (\@ARGV);
-my $pixmap = Qt::Pixmap ("images/inst_splash.png");
+my $pixmap = Qt::Pixmap;
+
+$pixmap -> loadFromData (PAR::read_file ("images/inst_splash.png"));
+
+my ($win, $icon);
 my $splash = InstSplash ($pixmap);
 my $font   = $splash -> font ();
 
 $splash -> show ();
-
 $font   -> setPixelSize (22);
 $splash -> setFont ($font);
 $splash -> repaint ();
 
-my $win  = InstWiz;
-my $icon = Qt::Pixmap::fromMimeSource ("icon.png");
+{
+  my    $show_splash = 1;
+  local $SIG {ALRM}  = sub { $show_splash = 0; };
 
-$win    -> setIcon ($icon);
-$app    -> setMainWidget ($win);
-$win    -> show ();
-$splash -> finish ($win);
+  # show splash screen for at least 3s
+  alarm (3);
+
+  $win  = InstWiz;
+  $icon = Qt::Pixmap::fromMimeSource ("icon.png");
+
+  $win -> setIcon ($icon);
+  $app -> setMainWidget ($win);
+  $win -> show ();
+
+  while ($show_splash)
+  {
+    select (undef, undef, undef, 0.1);
+  }
+
+  $splash -> finish ($win);
+}
 
 undef $pixmap;
 undef $splash;
